# pde-rk

[![CC BY 4.0][cc-by-shield]][cc-by]
[![PyPi version](https://badgen.net/pypi/v/pde-rk/)](https://pypi.org/project/pde-rk)

Functions for simulating PDE models with an adaptive Runge-Kutta scheme

## Installation

    pip install pde-rk

## Instructions

The repository contains an example notebook that demonstrates the method using the PAR polarity model (Goehring et al., 2011).
To run the notebook in Colab, click here: 

<a target="_blank" href="https://colab.research.google.com/github/tsmbland/pde-rk/blob/master/scripts/simulate_par.ipynb">
  <img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab" height=20/></a>



## License

This work is licensed under a
[Creative Commons Attribution 4.0 International License][cc-by].

[![CC BY 4.0][cc-by-image]][cc-by]

[cc-by]: http://creativecommons.org/licenses/by/4.0/

[cc-by-image]: https://i.creativecommons.org/l/by/4.0/88x31.png

[cc-by-shield]: https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg

